@@ -26,6 +26,8 @@ def cmd_mbox_common_opts(sp):
                     help='Filename to name the mbox file')
     sp.add_argument('-m', '--use-local-mbox', dest='localmbox', default=None,
                     help='Instead of grabbing a thread from lore, process this mbox file')
+    sp.add_argument('-C', '--no-cache', dest='nocache', action='store_true', default=False,
+                    help='Do not use local cache')
 
 
 def cmd_mbox(cmdargs):
@@ -53,7 +55,7 @@ def cmd():
         description='A tool to work with public-inbox patches',
         formatter_class=argparse.ArgumentDefaultsHelpFormatter,
     )
-    parser.add_argument('--version', action='version', version=b4.VERSION)
+    parser.add_argument('--version', action='version', version=b4.__VERSION__)
     parser.add_argument('-d', '--debug', action='store_true', default=False,
                         help='Add more debugging info to the output')
     parser.add_argument('-q', '--quiet', action='store_true', default=False,
